@@ -1,7 +1,7 @@
 //
 // BeagleDaemon.cs
 //
-// Copyright (C) 2004 Novell, Inc.
+// Copyright (C) 2004-2006 Novell, Inc.
 //
 
 //
@@ -47,6 +47,7 @@ namespace Beagle.Daemon {
 
 		private static bool arg_replace = false;
 		private static bool arg_disable_scheduler = false;
+		private static bool arg_indexing_test_mode = false;
 
 		public static bool StartServer ()
 		{
@@ -71,7 +72,7 @@ namespace Beagle.Daemon {
 				request.Send ();
 				// Give it a second to shut down the messaging server
 				Thread.Sleep (1000);
-			} while (! StartServer ());
+			} while (! StartServer ());			
 		}
 
 		private static void LogMemoryUsage ()
@@ -96,8 +97,8 @@ namespace Beagle.Daemon {
 		{
 			string usage =
 				"beagled: The daemon to the Beagle search system.\n" +
-				"Web page: http://www.gnome.org/projects/beagle\n" +
-				"Copyright (C) 2004-2005 Novell, Inc.\n\n";
+				"Web page: http://beagle-project.org\n" +
+				"Copyright (C) 2004-2006 Novell, Inc.\n\n";
 
 			usage +=
 				"Usage: beagled [OPTIONS]\n\n" +
@@ -107,6 +108,8 @@ namespace Beagle.Daemon {
 				"  --replace\t\tReplace a running daemon with a new instance.\n" +
 				"  --debug\t\tWrite out debugging information.\n" +
 				"  --debug-memory\tWrite out debugging information about memory use.\n" +
+				"  --indexing-test-mode\tRun in foreground, and exit when fully indexed.\n" +
+				"  --indexing-delay\tTime to wait before indexing.  (Default 60 seconds)\n" +
 				"  --deny-backend\tDeny a specific backend.\n" +
 				"  --allow-backend\tAllow a specific backend.\n" +
 				"  --list-backends\tList all the available backends.\n" +
@@ -136,9 +139,14 @@ namespace Beagle.Daemon {
 			// Fire up our server
 			if (! StartServer ()) {
 				if (arg_replace)
+				{
+#if ENABLE_WEBSERVICES
+					WebServiceBackEnd.Stop();
+#endif			
 					ReplaceExisting ();
+				}		
 				else {
-					Logger.Log.Fatal ("Could not set up the listener for beagle requests.  "
+					Logger.Log.Error ("Could not set up the listener for beagle requests.  "
 							  + "There is probably another beagled instance running.  "
 							  + "Use --replace to replace the running service");
 					Environment.Exit (1);
@@ -183,11 +191,35 @@ namespace Beagle.Daemon {
 			stopwatch.Stop ();
 
 			Logger.Log.Debug ("Daemon initialization finished after {0}", stopwatch);
-		
+
+			if (arg_indexing_test_mode) {
+				Thread.Sleep (1000); // Ugly paranoia: wait a second for the backends to settle.
+				Logger.Log.Debug ("Running in indexing test mode");
+				Scheduler.Global.EmptyQueueEvent += OnEmptySchedulerQueue;
+				Scheduler.Global.Add (null); // pulse the scheduler
+			}
 			return false;
 		}
 
-		public static int Main (string[] args)
+		static void OnEmptySchedulerQueue ()
+		{
+			Logger.Log.Debug ("Scheduler queue is empty: terminating immediately");
+			Shutdown.BeginShutdown ();
+			Environment.Exit (0); // Ugly work-around: We need to call Exit here to avoid deadlocking.
+		}
+
+		public static void Main (string[] args)
+		{
+			try {
+				DoMain (args);
+			} catch (Exception ex) {
+				Logger.Log.Error ("Unhandled exception thrown.  Exiting immediately.");
+				Logger.Log.Error (ex);
+				Environment.Exit (1);
+			}
+		}
+
+		public static void DoMain (string[] args)
 		{
 			// Process the command-line arguments
 			bool arg_debug = false;
@@ -208,6 +240,11 @@ namespace Beagle.Daemon {
 					Environment.Exit (0);
 					break;
 
+				case "--heap-buddy":
+					// Silently ignore the --heap-buddy argument: it gets handled
+					// in the wrapper script.
+					break;
+
 				case "--list-backends":
 					Console.WriteLine ("Current available backends:");
 					Console.Write (QueryDriver.ListBackends ());
@@ -236,6 +273,11 @@ namespace Beagle.Daemon {
 					arg_debug = true;
 					arg_debug_memory = true;
 					break;
+					
+				case "--indexing-test-mode":
+					arg_indexing_test_mode = true;
+					arg_fg = true;
+					break;
 
 				case "--allow-backend":
 					if (next_arg != null)
@@ -259,6 +301,19 @@ namespace Beagle.Daemon {
 					arg_disable_scheduler = true;
 					break;
 
+				case "--indexing-delay":
+					if (next_arg != null) {
+						try {
+							QueryDriver.IndexingDelay = Int32.Parse (next_arg);
+						} catch {
+							Console.WriteLine ("'{0}' is not a valid number of seconds", next_arg);
+							Environment.Exit (1);
+						}
+					}
+
+					++i;
+					break;
+
 				case "--autostarted":
 					if (! Conf.Searching.Autostart) {
 						Console.WriteLine ("Autostarting is disabled, not starting");
@@ -294,6 +349,11 @@ namespace Beagle.Daemon {
 				}
 			}
 
+			if (arg_indexing_test_mode) {
+				LuceneQueryable.OptimizeRightAway = true;
+			}
+				
+
 			// Bail out if we are trying to run as root
 			if (Environment.UserName == "root") {
 				Console.WriteLine ("You can not run beagle as root.");
@@ -303,25 +363,22 @@ namespace Beagle.Daemon {
 
 			MainLoopThread = Thread.CurrentThread;
 
-			// Initialize logging.
-			// If we saw the --debug arg, set the default logging level
-			// accordingly.
-			if (arg_debug)
-				Logger.DefaultLevel = LogLevel.Debug;
-
-			Logger.LogToFile (PathFinder.LogDir, "Beagle", arg_fg);
+			Log.Initialize (PathFinder.LogDir,
+					"Beagle", 
+					// FIXME: We always turn on full debugging output!  We are still
+					// debugging this code, after all...
+					//arg_debug ? LogLevel.Debug : LogLevel.Warn,
+					LogLevel.Debug,
+					arg_fg);
 
 			Logger.Log.Info ("Starting Beagle Daemon (version {0})", ExternalStringsHack.Version);
 			
-			// FIXME: This try/catch is to work around a bug in mono 1.1.3
-			try {
-				Logger.Log.Debug ("Command Line: {0}",
-						  Environment.CommandLine != null ? Environment.CommandLine : "(null)");
-			} catch (Exception ex) { }
+			Logger.Log.Debug ("Command Line: {0}",
+					  Environment.CommandLine != null ? Environment.CommandLine : "(null)");
 
 			if (! ExtendedAttribute.Supported) {
 				Logger.Log.Warn ("Extended attributes are not supported on this filesystem.  " +
-						 "Many search backends will not be available");
+						 "Performance will suffer as a result.");
 			}
 
 			// Start our memory-logging thread
@@ -353,36 +410,25 @@ namespace Beagle.Daemon {
 
 			Logger.Log.Debug ("Leaving BeagleDaemon.Main");
 
-			if (Logger.Log.Level == LogLevel.Debug) {
+			if (arg_debug) {
 				Thread.Sleep (500);
 				ExceptionHandlingThread.SpewLiveThreads ();
 			}
-
-			return 0;
 		}
 		
 
 		/////////////////////////////////////////////////////////////////////////////
 
-		// The integer values of the Mono.Posix.Signal enumeration don't actually
-		// match the Linux signal numbers of Linux.  Oops!
-		// This is fixed in Mono.Unix, but for the moment we want to maintain
-		// compatibility with mono 1.0.x.
-		const int ACTUAL_LINUX_SIGINT  = 2;
-		const int ACTUAL_LINUX_SIGQUIT = 3;
-		const int ACTUAL_LINUX_SIGTERM = 15;
-
 		static void SetupSignalHandlers ()
 		{
 			// Force OurSignalHandler to be JITed
 			OurSignalHandler (-1);
 
 			// Set up our signal handler
-			Mono.Posix.Syscall.sighandler_t sig_handler;
-			sig_handler = new Mono.Posix.Syscall.sighandler_t (OurSignalHandler);
-                        Mono.Posix.Syscall.signal (ACTUAL_LINUX_SIGINT, sig_handler);
-                        Mono.Posix.Syscall.signal (ACTUAL_LINUX_SIGQUIT, sig_handler);
-                        Mono.Posix.Syscall.signal (ACTUAL_LINUX_SIGTERM, sig_handler);
+			Mono.Unix.Native.Stdlib.signal (Mono.Unix.Native.Signum.SIGINT, OurSignalHandler);
+			Mono.Unix.Native.Stdlib.signal (Mono.Unix.Native.Signum.SIGTERM, OurSignalHandler);
+			if (Environment.GetEnvironmentVariable("BEAGLE_THERE_BE_NO_QUITTIN") == null)
+				Mono.Unix.Native.Stdlib.signal (Mono.Unix.Native.Signum.SIGQUIT, OurSignalHandler);
 		}
 
 		// Our handler triggers an orderly shutdown when it receives a signal.
