@@ -74,10 +74,6 @@ namespace Beagle.Daemon.EvolutionMailDriver {
 			Checkpoint ();
 		}
 
-		protected EvolutionMailQueryable Queryable {
-			get { return this.queryable; }
-		}
-
 		protected static void InitializeGMime ()
 		{
 			if (!gmime_initialized) {
@@ -108,6 +104,8 @@ namespace Beagle.Daemon.EvolutionMailDriver {
 		{
 			// FIXME: This is a little sketchy
 			this.queryable.FileAttributesStore.AttachLastWriteTime (this.CrawlFile.FullName, DateTime.UtcNow);
+
+			this.queryable.SetGeneratorProgress (this, 100);
 		}
 
 		public string StatusName {
@@ -198,8 +196,10 @@ namespace Beagle.Daemon.EvolutionMailDriver {
 		public override bool HasNextIndexable ()
 		{
 			if (this.account_name == null) {
-				if (!Setup ())
+				if (!Setup ()) {
+					this.queryable.RemoveGeneratorProgress (this);
 					return false;
+				}
 			}
 
 			if (this.mbox_fd < 0) {
@@ -363,10 +363,7 @@ namespace Beagle.Daemon.EvolutionMailDriver {
 			if (CheckFlags (flags, Camel.CamelFlags.AnsweredAll))
 				indexable.AddProperty (Property.NewFlag ("fixme:isAnsweredAll"));
 
-			MemoryStream stream = new MemoryStream ();
-			message.WriteToStream (stream);
-			stream.Seek (0, SeekOrigin.Begin);
-			indexable.SetBinaryStream (stream);
+			indexable.SetBinaryStream (message.Stream);
 
 			return indexable;
 		}
@@ -382,6 +379,8 @@ namespace Beagle.Daemon.EvolutionMailDriver {
 			if (this.file_size > 0 && offset > 0) {
 				progress = String.Format (" ({0}/{1} bytes {2:###.0}%)",
 							  offset, this.file_size, 100.0 * offset / this.file_size);
+
+				this.queryable.SetGeneratorProgress (this, (int) (100.0 * offset / this.file_size));
 			}
 
 			Logger.Log.Debug ("{0}: indexed {1} messages{2}",
@@ -601,8 +600,10 @@ namespace Beagle.Daemon.EvolutionMailDriver {
 		public override bool HasNextIndexable ()
 		{
 			if (this.account_name == null) {
-				if (!Setup ())
+				if (!Setup ()) {
+					this.queryable.RemoveGeneratorProgress (this);
 					return false;
+				}
 			}
 
 			if (this.mapping == null) {
@@ -615,6 +616,7 @@ namespace Beagle.Daemon.EvolutionMailDriver {
 				// Check to see if we even need to bother walking the summary
 				if (cache_loaded && this.queryable.FileAttributesStore.IsUpToDate (this.CrawlFile.FullName)) {
 					Logger.Log.Debug ("{0}: summary has not been updated; crawl unncessary", this.folder_name);
+					this.queryable.RemoveGeneratorProgress (this);
 					return false;
 				}
 			}
@@ -628,6 +630,7 @@ namespace Beagle.Daemon.EvolutionMailDriver {
 				} catch (Exception e) {
 					Logger.Log.Warn ("Unable to index {0}: {1}", this.folder_name,
 									 e.Message);
+					this.queryable.RemoveGeneratorProgress (this);
 					return false;
 				}
 			}
@@ -644,9 +647,9 @@ namespace Beagle.Daemon.EvolutionMailDriver {
 
 				// FIXME: This is kind of a hack, but it's the only way
 				// with the IndexableGenerator to handle our removals.
-				Scheduler.Task task = this.Queryable.NewRemoveTask (uri);
+				Scheduler.Task task = this.queryable.NewRemoveTask (uri);
 				task.Priority = Scheduler.Priority.Immediate;
-				this.Queryable.ThisScheduler.Add (task);
+				this.queryable.ThisScheduler.Add (task);
 			}
 
 			string progress = "";
@@ -747,7 +750,8 @@ namespace Beagle.Daemon.EvolutionMailDriver {
 			foreach (GMime.InternetAddress ia in addrs) {
 				if (!have_content) {
 					indexable.AddProperty (Property.NewKeyword ("fixme:to", ia.ToString (false)));
-					indexable.AddProperty (Property.NewKeyword ("fixme:to_address", ia.Addr));
+					indexable.AddProperty (Property.New ("fixme:to_address", ia.Addr));
+					indexable.AddProperty (Property.New ("fixme:to_sanitized", StringFu.SanitizeEmail (ia.Addr)));
 					indexable.AddProperty (Property.New ("fixme:to_name", ia.Name));
 				}
 
@@ -760,7 +764,8 @@ namespace Beagle.Daemon.EvolutionMailDriver {
 			foreach (GMime.InternetAddress ia in addrs) {
 				if (!have_content) {
 					indexable.AddProperty (Property.NewKeyword ("fixme:cc", ia.ToString (false)));
-					indexable.AddProperty (Property.NewKeyword ("fixme:cc_address", ia.Addr));
+					indexable.AddProperty (Property.New ("fixme:cc_address", ia.Addr));
+					indexable.AddProperty (Property.New ("fixme:cc_sanitized", StringFu.SanitizeEmail (ia.Addr)));
 					indexable.AddProperty (Property.New ("fixme:cc_name", ia.Name));
 				}
 
@@ -773,7 +778,8 @@ namespace Beagle.Daemon.EvolutionMailDriver {
 			foreach (GMime.InternetAddress ia in addrs) {
 				if (!have_content) {
 					indexable.AddProperty (Property.NewKeyword ("fixme:from", ia.ToString (false)));
-					indexable.AddProperty (Property.NewKeyword ("fixme:from_address", ia.Addr));
+					indexable.AddProperty (Property.New ("fixme:from_address", ia.Addr));
+					indexable.AddProperty (Property.New ("fixme:from_sanitized", StringFu.SanitizeEmail (ia.Addr)));
 					indexable.AddProperty (Property.New ("fixme:from_name", ia.Name));
 				}
 
@@ -828,6 +834,8 @@ namespace Beagle.Daemon.EvolutionMailDriver {
 								  this.summary.header.count,
 								  100.0 * this.count / this.summary.header.count);
 
+					this.queryable.SetGeneratorProgress (this, (int) (100.0 * this.count / this.summary.header.count));
+
 				}
 				
 				Logger.Log.Debug ("{0}: indexed {1} messages{2}",
