@@ -44,6 +44,7 @@ namespace Beagle.Daemon.FileSystemQueryable {
 		private const string SplitFilenamePropKey = "beagle:Filename";
 		public const string ExactFilenamePropKey = "beagle:ExactFilename";
 		public const string TextFilenamePropKey = "beagle:TextFilename";
+		public const string NoPunctFilenamePropKey = "beagle:NoPunctFilename";
 		public const string FilenameExtensionPropKey = "beagle:FilenameExtension";
 		public const string ParentDirUriPropKey = LuceneQueryingDriver.PrivateNamespace + "ParentDirUri";
 		public const string IsDirectoryPropKey = LuceneQueryingDriver.PrivateNamespace + "IsDirectory";
@@ -138,9 +139,19 @@ namespace Beagle.Daemon.FileSystemQueryable {
 								     Guid      parent_id,
 								     bool      mutable)
 		{
-			string no_ext, ext;
+			StringBuilder sb;
+			sb = new StringBuilder ();
+
+			string no_ext, ext, no_punct;
 			no_ext = Path.GetFileNameWithoutExtension (name);
-			ext = Path.GetExtension (name);
+			ext = Path.GetExtension (name).ToLower ();
+			
+			sb.Append (no_ext);
+			for (int i = 0; i < sb.Length; ++i)
+				if (! Char.IsLetterOrDigit (sb [i]))
+					sb [i] = ' ';
+			no_punct = sb.ToString ();
+
 
 			Property prop;
 
@@ -152,6 +163,10 @@ namespace Beagle.Daemon.FileSystemQueryable {
 			prop.IsMutable = mutable;
 			indexable.AddProperty (prop);
 
+			prop = Property.New (NoPunctFilenamePropKey, no_punct);
+			prop.IsMutable = mutable;
+			indexable.AddProperty (prop);
+
 			prop = Property.NewKeyword (FilenameExtensionPropKey, ext);
 			prop.IsMutable = mutable;
 			indexable.AddProperty (prop);
@@ -898,11 +913,15 @@ namespace Beagle.Daemon.FileSystemQueryable {
 				return RequiredAction.Index;
 			}
 
-			// If the inode ctime is different that the time we last
-			// set file attributes, we might have been moved or copied.
-			if (attr.LastAttrTime != last_attr_time) {
+			// If the inode ctime is newer than the last time we last
+			// set file attributes, we might have been moved.  We don't
+			// strictly compare times due to the fact that although
+			// setting xattrs changes the ctime, if we don't have write
+			// access our metadata will be stored in sqlite, and the
+			// ctime will be at some point in the past.
+			if (attr.LastAttrTime < last_attr_time) {
 				if (Debug)
-					Logger.Log.Debug ("*** CTime has changed, checking last known path ({0} vs {1})", attr.LastAttrTime, last_attr_time);
+					Logger.Log.Debug ("*** CTime is newer, checking last known path ({0} vs {1})", attr.LastAttrTime, last_attr_time);
 
 				last_known_path = UniqueIdToFullPath (attr.UniqueId);
 
