@@ -37,6 +37,8 @@ namespace Beagle.Daemon {
 
 	public class Filter {
 
+		static private bool Debug = false;
+
 		// Derived classes always must have a constructor that
 		// takes no arguments.
 		public Filter () { }
@@ -101,6 +103,7 @@ namespace Beagle.Daemon {
 
 		private string this_mime_type = null;
 		private string this_extension = null;
+		private ArrayList indexable_properties = null;
 
 		public string MimeType {
 			get { return this_mime_type; }
@@ -112,6 +115,13 @@ namespace Beagle.Daemon {
 			set { this_extension = value; }
 		}
 
+		// allow the filter to access the properties
+		// set by indexable
+		public ArrayList IndexableProperties {
+			get { return indexable_properties; }
+			set { indexable_properties = value; }
+		}
+		
 		//////////////////////////
 		
 		private bool crawl_mode = false;
@@ -229,7 +239,9 @@ namespace Beagle.Daemon {
 		
 		public void AppendText (string str)
 		{
-			//Logger.Log.Debug ("AppendText (\"{0}\")", str);
+			if (Debug)
+				Logger.Log.Debug ("AppendText (\"{0}\")", str);
+
 			if (! IsFrozen && str != null && str != "")
 				AppendText (str, IsHot ? str : null);
 		}
@@ -267,7 +279,9 @@ namespace Beagle.Daemon {
 			if (last_was_structural_break)
 				return;
 
-			//Logger.Log.Debug ("AppendWhiteSpace ()");
+			if (Debug)
+				Logger.Log.Debug ("AppendWhiteSpace ()");
+
 			if (NeedsWhiteSpace (textPool)) {
 				textPool.Add (" ");
 				if (snippetWriter != null)
@@ -366,7 +380,8 @@ namespace Beagle.Daemon {
 			tempFile = Path.GetTempFileName ();
                         FileStream file_stream = File.OpenWrite (tempFile);
 
-			//Logger.Log.Debug ("Storing text in tempFile {0}", tempFile);
+			if (Debug)
+				Logger.Log.Debug ("Storing text in tempFile {0}", tempFile);
 
                         // When we dump the contents of a reader into a file, we
                         // expect to use it again soon.
@@ -400,7 +415,8 @@ namespace Beagle.Daemon {
 			tempFile = Path.GetTempFileName ();
                         FileStream file_stream = File.OpenWrite (tempFile);
 			
-			//Logger.Log.Debug ("Storing stream in tempFile {0}", tempFile);
+			if (Debug)
+				Logger.Log.Debug ("Storing stream in tempFile {0}", tempFile);
 
                         // When we dump the contents of a reader into a file, we
                         // expect to use it again soon.
