@@ -31,6 +31,7 @@ using System.Net.Sockets;
 using System.Reflection;
 using System.Threading;
 using System.Xml.Serialization;
+using Mono.Unix;
 
 using Beagle.Util;
 
@@ -39,7 +40,7 @@ namespace Beagle.Daemon {
 	class ConnectionHandler {
 
 		private static int connection_count = 0;
-		private static XmlSerializer serializer = new XmlSerializer (typeof (ResponseWrapper), ResponseMessage.Types);
+		public static XmlSerializer serializer = null;
 
 		private object client_lock = new object ();
 		private object blocking_read_lock = new object ();
@@ -66,7 +67,7 @@ namespace Beagle.Daemon {
 					XmlFu.SerializeUtf8 (serializer, mem_stream, new ResponseWrapper (response));
 					mem_stream.Seek (0, SeekOrigin.Begin);
 					StreamReader r = new StreamReader (mem_stream);
-					Logger.Log.Debug ("Sending response:\n{0}", r.ReadToEnd ());
+					Logger.Log.Debug ("Sending response:\n{0}\n", r.ReadToEnd ());
 					mem_stream.Seek (0, SeekOrigin.Begin);
 					mem_stream.WriteTo (this.client.GetStream ());
 					mem_stream.Close ();
@@ -225,6 +226,12 @@ namespace Beagle.Daemon {
 
 			buffer_stream.Seek (0, SeekOrigin.Begin);
 
+#if ENABLE_XML_DUMP
+			StreamReader r = new StreamReader (buffer_stream);
+			Logger.Log.Debug ("Received request:\n{0}\n", r.ReadToEnd ());
+			buffer_stream.Seek (0, SeekOrigin.Begin);
+#endif
+
 			try {
 				RequestWrapper wrapper = (RequestWrapper) req_serializer.Deserialize (buffer_stream);
 				
@@ -341,6 +348,8 @@ namespace Beagle.Daemon {
 			this.running = true;
 
 			Shutdown.WorkerStart (this, String.Format ("server '{0}'", socket_path));
+			if (ConnectionHandler.serializer == null)
+				ConnectionHandler.serializer = new XmlSerializer (typeof (ResponseWrapper), ResponseMessage.Types);
 
 			while (this.running) {
 				UnixClient client;
@@ -380,7 +389,8 @@ namespace Beagle.Daemon {
 
 		public void Start ()
 		{
-			ExceptionHandlingThread.Start (new ThreadStart (this.Run));
+			if (!Shutdown.ShutdownRequested)
+				ExceptionHandlingThread.Start (new ThreadStart (this.Run));
 		}
 
 		public void Stop ()
